%CANAL
%function bitsr=canalt(bitst,BER)
%Entradas:
%bitst:bits de la trama antes de pasar por el canal.
%BER:tasa de error de bit del canal.
%Salidas:
%bitsr:bits de la trama tras pasar por el canal.
function bitsr=canalt(bitst,BER)
pos=(rand(1,114)<BER);
for i=1:114
   if(pos(i)==1)
      if(bitst(i)=='1')
         bitsr(i)='0';
      else
         bitsr(i)='1';
      end
   else
      bitsr(i)=bitst(i);
   end
end